package com.fzm.common.utils;

import cn.hutool.core.util.IdUtil;
import com.fzm.common.enums.ResultCode;
import com.fzm.common.exception.GlobalException;
import com.fzm.common.properties.ObsProperties;
import com.obs.services.ObsClient;
import com.obs.services.model.DeleteObjectResult;
import com.obs.services.model.ObsObject;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.net.URLEncoder;

/**
 * @author tangtuo
 * @date 2021/6/29 16:07
 *
 * <p>
 * 华为云对象存储服务工具类
 * </p>
 */
@Slf4j
@Component
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class ObsUtil {
    private final ObsClient obsClient;
    private final ObsProperties obsProperties;
    private final HttpServletResponse response;

    /**
     * 上传对象
     *
     * @param file
     * @return
     */
    public String putObject(MultipartFile file) throws IOException {
        String originalFilename = file.getOriginalFilename();
        if (StringUtils.isBlank(originalFilename)) {
            throw GlobalException.newException(ResultCode.VALIDATE_FAILED, "文件名不能为空");
        }
        String objectName = IdUtil.simpleUUID().concat("/").concat(originalFilename.replaceAll(" ", ""));
        obsClient.putObject(obsProperties.getBucket(), objectName, file.getInputStream());
        return String.format("https://%s.%s/%s", obsProperties.getBucket(), obsProperties.getEndPoint(), objectName);
    }


    /**
     * 下载对象
     *
     * @param fileUrl  文件地址
     * @param fileName 文件名
     */
    public void downloadFile(String fileUrl, String fileName) {
        try {
            // 文件名以附件的形式下载
            response.setHeader("Content-Disposition", "attachment;filename=" + URLEncoder.encode(fileName, "UTF-8"));
        } catch (UnsupportedEncodingException e) {
            log.error(e.getMessage(), e);
            throw GlobalException.newException(ResultCode.FILE_DOWNLOAD_ERROR, e.getMessage());
        }
        String objectName = fileUrl.substring(String.format("https://%s.%s/", obsProperties.getBucket(), obsProperties.getEndPoint()).length());
        ObsObject object = obsClient.getObject(obsProperties.getBucket(), objectName);
        try {
            // 读取文件内容。
            InputStream inputStream = object.getObjectContent();
            BufferedInputStream in = new BufferedInputStream(inputStream);// 把输入流放入缓存流
            ServletOutputStream outputStream = response.getOutputStream();
            BufferedOutputStream out = new BufferedOutputStream(outputStream);// 把输出流放入缓存流
            byte[] buffer = new byte[1024];
            int len;
            while ((len = in.read(buffer)) != -1) {
                out.write(buffer, 0, len);
            }
            out.flush();
            out.close();
            in.close();
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw GlobalException.newException(ResultCode.FILE_DOWNLOAD_ERROR, e.getMessage());
        }
    }


    /**
     * 删除对象
     *
     * @param fileUrl
     * @return
     */
    public boolean delete(String fileUrl) {
        return true;
//        String objectName = fileUrl.substring(String.format("https://%s.%s/", obsProperties.getBucket(), obsProperties.getEndPoint()).length());
//        DeleteObjectResult result = obsClient.deleteObject(obsProperties.getBucket(), objectName);
//        return !result.isDeleteMarker();
    }


    public static void main(String[] args) throws Exception{
        String endPoint = "obs.cn-east-3.myhuaweicloud.com";
        String ak = "CYEVMBJZJA1EXTNOOIGQ";
        String sk = "L4jnRHdXINzcOpUhxkrLSfHrOgOBGk10xRoPPple";
        String bucketName = "inmvo-obs";
        // 创建ObsClient实例
        ObsClient obsClient = new ObsClient(ak, sk, endPoint);
        String url = "https://inmvo-obs.obs.cn-east-3.myhuaweicloud.com/01432bdaffa747e99286f40886380859/123.jpg";
        String objectName = url.substring(String.format("https://%s.%s/", bucketName, endPoint).length());
        System.out.println(objectName);
        DeleteObjectResult deleteObjectResult = obsClient.deleteObject(bucketName, objectName);
        System.out.println(deleteObjectResult);
//        String objectName = IdUtil.simpleUUID().concat("/").concat("123.jpg");
//        File file = new File("C:\\Users\\33\\Downloads\\QQ图片20220810152256.jpg");
//
//        PutObjectResult putObjectResult = obsClient.putObject(bucketName, objectName, file);
//        System.out.println(putObjectResult);
//        System.out.printf("https://%s.%s/%s%n", bucketName, endPoint, objectName);
    }


}
