package com.fzm.portal.controller;

import com.fzm.common.annotation.Authentication;
import com.fzm.common.entity.Order;
import com.fzm.common.entity.dto.CopyrightOrderDto;
import com.fzm.common.entity.dto.NftOrderDto;
import com.fzm.common.entity.vo.OrderVo;
import com.fzm.common.model.ResponseModel;
import com.fzm.common.service.ApplyOrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author wt
 * @date 2022/5/23
 */
@RestController
@Api(tags = "版权/NFT申请并下单")
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class ApplyOrderController {

    private final ApplyOrderService applyOrderService;

    @Authentication
    @PostMapping("/copyright/apply/submit-order")
    @ApiOperation("提交申请并下单")
    public ResponseModel<OrderVo> submitOrder(@Validated @RequestBody CopyrightOrderDto orderDto) {
        Order order = applyOrderService.submitOrder(orderDto);
        return ResponseModel.success(new OrderVo(order));
    }

    @Authentication
    @PostMapping(value = "/copyright/apply/update-order")
    @ApiOperation(value = "编辑并下单")
    public ResponseModel<OrderVo> updateOrder(@Validated @RequestBody CopyrightOrderDto orderDto) {
        Order order = applyOrderService.updateOrder(orderDto);
        return ResponseModel.success(new OrderVo(order));
    }

    @Authentication
    @PostMapping(value = "/nft/apply/submit-order")
    @ApiOperation(value = "nft申请并下单")
    public ResponseModel<OrderVo> nftOrder(@Validated @RequestBody NftOrderDto orderDto) {
        Order order = applyOrderService.nftOrder(orderDto);
        return ResponseModel.success(new OrderVo(order));
    }
}
